==> iReport-0.0.2.zip: iReport-0.0.2/src/com/businesslogic/ireport/OperationType.java <==
/*
 *  iReport  --  Visual designer for generating JasperReports Documents
 *  Copyright (C) 2002  Giulio Toffoli gt@businesslogic.it
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Giulio Toffoli
 *  Via T.Aspetti, 233
 *  35100 Padova ITALY
 *  gt@businesslogic.it
 */
package com.businesslogic.ireport;

public class OperationType
{
	public static final int ALIGN_LEFT				=1;
	public static final int ALIGN_RIGHT				=2;
	public static final int ALIGN_TOP				=3;
	public static final int ALIGN_BOTTOM				=4;
	public static final int ALIGN_CENTER_VERTICALLY	=5;
	public static final int ALIGN_CENTER_HORIZONTALLY	=6;
	public static final int ALIGN_CENTER				=7;
	public static final int ALIGN_VERTICAL_AXIS		=8;
	public static final int ALIGN_HORIZONTAL_AXIS	=9;
	
	public static final int SAME_SIZE				=10;
	public static final int SAME_WIDTH				=11;
	public static final int SAME_HEIGHT				=12;
	
	public static final int SPACE_HORIZONTALLY		=12;
	public static final int SPACE_VERTICALLY		=13;
	
	public static final int ALIGN_TOP_TO_BAND	=14;
}

==> iReport-0.0.7.zip: iReport-0.0.7/src/com/businesslogic/ireport/OperationType.java <==
/*
 *  iReport  --  Visual designer for generating JasperReports Documents
 *  Copyright (C) 2002  Giulio Toffoli gt@businesslogic.it
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Giulio Toffoli
 *  Via T.Aspetti, 233
 *  35100 Padova ITALY
 *  gt@businesslogic.it
 */
package com.businesslogic.ireport;

public class OperationType
{
	public static final int ALIGN_LEFT				=1;
	public static final int ALIGN_RIGHT				=2;
	public static final int ALIGN_TOP				=3;
	public static final int ALIGN_BOTTOM				=4;
	public static final int ALIGN_CENTER_VERTICALLY	=5;
	public static final int ALIGN_CENTER_HORIZONTALLY	=6;
	public static final int ALIGN_CENTER				=7;
	public static final int ALIGN_VERTICAL_AXIS		=8;
	public static final int ALIGN_HORIZONTAL_AXIS	=9;
	
	public static final int SAME_SIZE				=10;
	public static final int SAME_WIDTH				=11;
	public static final int SAME_HEIGHT				=12;
	
	public static final int SPACE_HORIZONTALLY		=12;
	public static final int SPACE_VERTICALLY		=13;
	
	public static final int ALIGN_TOP_TO_BAND		=14;
	public static final int BRING_TO_FRON			=15;
	public static final int SEND__TO_BACK			=16;
	
	public static final int HSPACE_MAKE_EQUAL		=17;
	public static final int HSPACE_INCREASE		    =18;
	public static final int HSPACE_DECREASE			=19;
	public static final int HSPACE_REMOVE			=20;
	
	public static final int VSPACE_MAKE_EQUAL		=21;
	public static final int VSPACE_INCREASE		    =22;
	public static final int VSPACE_DECREASE			=23;
	public static final int VSPACE_REMOVE			=24;
}
